annotation/annotation library

Classes

FlutterInheritedModel
An annotation that designates a model class to be generated as an InheritedModel widget.
FlutterInheritedState
An annotation used to define a sub-state within a model class.
InheritedModelState
An annotation that designates a state field to be managed by the InheritedModel.

Constants

inheritedModelState → const InheritedModelState
An annotation that designates a state field to be managed by the InheritedModel.