event property

Type? event
final

Specifies the Event type to use for handling one-way events between the model and the UI.

The specified Event class (usually defined as a sealed class) can be used to trigger UI interactions from the model, such as showing a SnackBar or navigating to a new page.

Implementation

final Type? event;