name property
Specifies the name of the InheritedModel widget to be generated.
If not specified, the name of the model class will be used.
For example, the MyModel class will become MyModelInheritedModel.
Implementation
final String? name;
Specifies the name of the InheritedModel widget to be generated.
If not specified, the name of the model class will be used.
For example, the MyModel class will become MyModelInheritedModel.
final String? name;