useSingleTickerProvider property
Determines whether to add SingleTickerProviderStateMixin to the widget.
Set to true if a single Ticker is required, such as for an AnimationController.
Implementation
final bool useSingleTickerProvider;
Determines whether to add SingleTickerProviderStateMixin to the widget.
Set to true if a single Ticker is required, such as for an AnimationController.
final bool useSingleTickerProvider;