useTickerProvider property

bool useTickerProvider
final

Determines whether to add TickerProviderStateMixin to the widget.

Set to true if multiple Tickers are required, such as for multiple AnimationControllers. Cannot be set to true at the same time as useSingleTickerProvider.

Implementation

final bool useTickerProvider;