name property
Specifies the name of the sub-state class to be generated.
Generally, this does not need to be specified, as build_runner manages the name automatically.
Implementation
final String? name;
Specifies the name of the sub-state class to be generated.
Generally, this does not need to be specified, as build_runner manages the name automatically.
final String? name;