useAsyncWorker property

bool useAsyncWorker
final

Determines whether to use AsyncWorker for safely handling asynchronous tasks within the sub-state class.

If set to true, the asyncWorker object can be used to prevent asynchronous callbacks from being executed after the widget has been disposed.

Implementation

final bool useAsyncWorker;