InheritedModelState class final

An annotation that designates a state field to be managed by the InheritedModel.

Fields with this annotation will have logic automatically generated by build_runner to detect state changes and rebuild only the widgets that depend on that state.

Example:

@inheritedModelState
int counter;

Constructors

InheritedModelState()
An annotation that designates a state field to be managed by the InheritedModel.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited