FlutterInheritedModel class final

Constructors

FlutterInheritedModel({String? name, bool useLifecycleState = false, bool useAsyncWorker = false, bool useSingleTickerProvider = false, bool useTickerProvider = false, Type? event})
const

Properties

event Type?
final
hashCode int
The hash code for this object.
no setterinherited
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useAsyncWorker bool
final
useLifecycleState bool
final
useSingleTickerProvider bool
final
useTickerProvider bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited