useLifecycleState property
Determines whether the model should receive widget app lifecycle events.
If set to true, you can override app lifecycle callback methods such as onDidChangeAppLifecycleState within the model class to implement
logic for state initialization, resource disposal, etc.
Implementation
final bool useLifecycleState;