inheritedModelState top-level constant
InheritedModelState
const inheritedModelState
An annotation that designates a state field to be managed by the InheritedModel.
Fields with this annotation will have logic automatically generated by build_runner
to detect state changes and rebuild only the widgets that depend on that state.
Example:
@inheritedModelState
int counter;
Implementation
const inheritedModelState = InheritedModelState();